@@ -1,7 +1,7 @@
 // qsynth.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2025, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2026, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -78,14 +78,6 @@ public:
 	// and raise its proper main widget...
 	bool setup();
 
-	void loadTranslations(const QString& sLanguage);
-
-	// Install Prefix Location
-	static QString prefixPath;
-
-	// Translations Location
-	static QString translationsPath;
-
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #ifdef CONFIG_XUNIQUE
 #ifdef CONFIG_X11
