@@ -1,7 +1,7 @@
 // qsynthOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2025, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2026, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -106,9 +106,6 @@ public:
 	// Available custom engines list.
 	QStringList engines;
 
-	// Language choices
-	QString sLanguage;
-
 	// Engine management methods.
 	void newEngine(qsynthEngine *pEngine);
 	bool renameEngine(qsynthEngine *pEngine);
